@@ -1,5 +1,5 @@
 import numpy as np
-import argparse
+import textwrap
 from ..fir_filter_module import FIRFilterModule
 
 ARGS_DESC = """
@@ -69,7 +69,8 @@ ARGS_DESC = """
     exec_cmd = joule-mean-filter
 
     [Arguments]
-    window = 11 # must be odd
+    # must be odd
+    window = 11 
 
     [Inputs]
     input = /path/to/input
@@ -84,10 +85,13 @@ class MeanFilter(FIRFilterModule):
     """Compute the moving average of the input"""
     
     def custom_args(self, parser):  # pragma: no cover
-        parser.add_argument("--window", type=int,
-                            help="window length (odd)")
-        parser.description = ARGS_DESC
-        parser.formatter_class = argparse.RawDescriptionHelpFormatter
+        grp = parser.add_argument_group("module",
+                                        "module specific arguments")
+        
+        grp.add_argument("--window", type=int, required=True,
+                         help="window length (odd)")
+
+        parser.description = textwrap.dedent(ARGS_DESC)
 
     def make_filter(self, parsed_args):
         window = parsed_args.window
