@@ -1,11 +1,11 @@
 import asyncio
 import argparse
+import logging
 from typing import Dict
-from joule.models.pipes.pipe import Pipe as Pipe
 
+from joule.models.pipes.pipe import Pipe as Pipe
+from joule import errors
 from . import base_module
-from joule.errors import ConfigurationError
-#from joule.models import ConfigurationError
 
 
 class CompositeModule(base_module.BaseModule):
@@ -28,12 +28,14 @@ class CompositeModule(base_module.BaseModule):
 
         assert False, "implement in child class"  # pragma: no cover
 
-    def run_as_task(self, parsed_args, app, loop):
-        coro = self._build_pipes(parsed_args, loop)
-        (pipes_in, pipes_out) = loop.run_until_complete(coro)
-        coro = self.setup(parsed_args,
-                          pipes_in,
-                          pipes_out,
-                          loop)
-        tasks = loop.run_until_complete(coro)
+    async def run_as_task(self, parsed_args, app, loop) -> asyncio.Task:
+        try:
+            (pipes_in, pipes_out) = await self._build_pipes(parsed_args)
+        except errors.ApiError as e:
+            logging.error(str(e))
+            return loop.create_task(asyncio.sleep(0))
+        tasks = await self.setup(parsed_args,
+                                 pipes_in,
+                                 pipes_out,
+                                 loop)
         return asyncio.gather(*tasks)
