@@ -6,6 +6,7 @@ import sys
 
 from joule.client.base_module import BaseModule
 from joule.models.pipes import Pipe
+from joule import errors
 
 
 class ReaderModule(BaseModule):
@@ -52,19 +53,22 @@ class ReaderModule(BaseModule):
         """
         assert False, "implement in child class"  # pragma: no cover
 
-    def run_as_task(self, parsed_args, app, loop):
+    async def run_as_task(self, parsed_args, app, loop):
         # check if we should use stdout (no fd's and no configs)
         if (parsed_args.pipes == "unset" and
                 parsed_args.module_config == "unset"):
             output = StdoutPipe()
         else:
-            coro = self._build_pipes(parsed_args, loop)
-            (pipes_in, pipes_out) = loop.run_until_complete(coro)
-            if 'output' not in pipes_out:
-                logging.error("Reader Module must a have a single output called 'output'")
+            try:
+                (pipes_in, pipes_out) = await self._build_pipes(parsed_args)
+            except errors.ApiError as e:
+                logging.error(str(e))
                 return loop.create_task(asyncio.sleep(0))
-            output = pipes_out['output']
-        loop.run_until_complete(self.setup(parsed_args, app, output))
+            if len(pipes_out.keys()) != 1:
+                logging.error("Reader module must have a single output")
+                return loop.create_task(asyncio.sleep(0))
+            output = list(pipes_out.values())[0]
+        await self.setup(parsed_args, app, output)
         return loop.create_task(self.run(parsed_args, output))
 
 
