@@ -1,6 +1,7 @@
 from sqlalchemy.orm import relationship
 from sqlalchemy import (Column, Integer, String,
                         Boolean, Enum, ForeignKey)
+from sqlalchemy.dialects.postgresql import BIGINT
 from typing import List, Dict, TYPE_CHECKING
 import configparser
 import enum
@@ -10,7 +11,7 @@ from operator import attrgetter
 from joule.models.meta import Base
 from joule.errors import ConfigurationError
 from joule.models.data_store.data_store import StreamInfo
-from joule.models import element
+from joule.models import element, annotation
 
 if TYPE_CHECKING:
     from joule.models import (Folder)  # pragma: no cover
@@ -29,6 +30,8 @@ class Stream(Base):
 
     """
     __tablename__ = 'stream'
+    __table_args__ = {"schema": "metadata"}
+
     id: int = Column(Integer, primary_key=True)
     name: str = Column(String, nullable=False)
 
@@ -54,14 +57,17 @@ class Stream(Base):
 
     KEEP_ALL = -1
     KEEP_NONE = 0
-    keep_us: int = Column(Integer, default=KEEP_ALL)
+    keep_us: int = Column(BIGINT, default=KEEP_ALL)
 
     description: str = Column(String)
-    folder_id: int = Column(Integer, ForeignKey('folder.id'))
+    folder_id: int = Column(Integer, ForeignKey('metadata.folder.id'))
     folder: "Folder" = relationship("Folder", back_populates="streams")
     elements: List[element.Element] = relationship("Element",
                                                    cascade="all, delete-orphan",
                                                    back_populates="stream")
+    annotations: List[annotation.Annotation] = relationship("Annotation",
+                                                            cascade="all, delete-orphan",
+                                                            back_populates="stream")
 
     def merge_configs(self, other: 'Stream') -> None:
         # replace configurable attributes with other's values
@@ -130,17 +136,17 @@ class Stream(Base):
         bool: true if the stream resides on a remote system
         """
         try:
-            return self._remote_url is not None
+            return self._remote_node is not None
         except AttributeError:
             return False
 
     @property
-    def remote_url(self) -> str:
+    def remote_node(self) -> str:
         """
         str: URL of remote host, blank if the stream is local
         """
         try:
-            return self._remote_url
+            return self._remote_node
         except AttributeError:
             return ''
 
@@ -154,14 +160,14 @@ class Stream(Base):
         except AttributeError:
             return ''
 
-    def set_remote(self, url: str, path: str):
+    def set_remote(self, node: str, path: str):
         """
         Associate the stream with a remote system
         Args:
             url: remote URL
             path: stream path on remote system
         """
-        self._remote_url = url
+        self._remote_node = node
         self._remote_path = path
 
     def to_json(self, info: Dict[int, StreamInfo] = None) -> Dict:
@@ -182,7 +188,8 @@ class Stream(Base):
             'id': self.id,
             'name': self.name,
             'description': self.description,
-            'datatype': self.datatype.name,
+            'datatype': self.datatype.name.lower(),
+            'layout': self.layout,
             'keep_us': self.keep_us,
             'is_configured': self.is_configured,
             'is_source': self.is_source,
@@ -215,12 +222,16 @@ def from_json(data: Dict) -> Stream:
 
     """
     elements = []
+    index = 0
     for item in data["elements"]:
+        item["index"] = index
         elements.append(element.from_json(item))
+        index += 1
+
     return Stream(id=data["id"],
-                  name=data["name"],
+                  name=validate_name(data["name"]),
                   description=data["description"],
-                  datatype=Stream.DATATYPE[data["datatype"]],
+                  datatype=validate_datatype(data["datatype"].upper()),
                   keep_us=data["keep_us"],
                   decimate=data["decimate"],
                   is_configured=data["is_configured"],
