@@ -14,7 +14,7 @@ from joule.models.stream import Stream
 from joule.models.folder import get_stream_path
 from joule.errors import SubscriptionError
 from joule.models import pipes
-from joule.models.pipes.errors import EmptyPipe
+from joule.models.pipes.errors import EmptyPipe, PipeError
 
 # custom types
 Loop = asyncio.AbstractEventLoop
@@ -23,7 +23,8 @@ Subscribers = Dict[Stream, List[pipes.Pipe]]
 popen_lock = None
 log = logging.getLogger('joule')
 
-SOCKET_BASE = "wattsworth.joule.%d"
+SOCKET_BASE = "/tmp/joule/module%d"
+API_SOCKET = "/tmp/joule/api"
 
 
 def _initialize_popen_lock():
@@ -132,18 +133,18 @@ class Worker:
         return self.module.description
 
     @property
-    def has_interface(self):
-        return self.module.has_interface
+    def is_app(self):
+        return self.module.is_app
 
     @property
     def interface_socket(self):
-        if self.module.has_interface:
-            return b'\x00' + (SOCKET_BASE % self.module.uuid).encode('ascii')
+        if self.module.is_app:
+            return SOCKET_BASE % self.module.uuid
         return None
 
     @property
     def interface_name(self):
-        if self.module.has_interface:
+        if self.module.is_app:
             return SOCKET_BASE % self.module.uuid
         return "none"
 
@@ -270,6 +271,7 @@ class Worker:
             self.log("ERROR: cannot start module: \n\t%s" % e)
             self.module.status = Module.STATUS.FAILED
             log.error("Cannot start [%s]: %s" % (self.module.name, e))
+
             self._close_child_fds()
             popen_lock.release()
             await self._close_connections()
@@ -362,6 +364,14 @@ class Worker:
 
         except (EmptyPipe, asyncio.CancelledError):
             pass
+        except PipeError as e:
+            if 'closed pipe' in str(e):
+                # during shutdown the pipe may be closed but
+                # another read might be attempted by the output_handler
+                pass
+            else:
+                log.warning("Worker %s, pipe %s: %s" % (
+                    self.name, child_output.name, str(e)))
 
     async def _subscribe_to_inputs(self,
                                    subscribe: Callable[[Stream, pipes.Pipe, Loop], Callable],
@@ -389,15 +399,22 @@ class Worker:
         cmd = shlex.split(self.module.exec_cmd)
         output_args = {}
         for c in self.output_connections:
-            output_args[c.name] = {'fd': c.child_fd, 'stream': c.stream.to_json()}
+            output_args[c.name] = {'fd': c.child_fd, 'id': c.stream.id, 'layout': c.stream.layout}
         input_args = {}
         for c in self.input_connections:
-            input_args[c.name] = {'fd': c.child_fd, 'stream': c.stream.to_json()}
+            input_args[c.name] = {'fd': c.child_fd, 'id': c.stream.id, 'layout': c.stream.layout}
         cmd += ["--pipes", json.dumps(json.dumps(
             {'outputs': output_args, 'inputs': input_args}))]
         # add a socket if the module has a web interface
-        if self.module.has_interface:
+        if self.module.is_app:
             cmd += ["--socket", self.interface_name]
+            # remove the socket file if it exists
+            if os.path.exists(self.interface_name):
+                log.warning("forcibly removing app socket [%s]" % self.interface_name)
+                os.unlink(self.interface_name)
+
+        # API access
+        cmd += ["--api-socket", API_SOCKET]
         for (arg, value) in self.module.arguments.items():
             cmd += ["--" + arg, value]
         return cmd
@@ -411,6 +428,9 @@ class Worker:
             await c.disconnect()
         self.output_connections = []
         self.input_connections = []
+        # remove the socket file if it exists
+        if self.interface_socket is not None and os.path.exists(self.interface_socket):
+            os.unlink(self.interface_socket)
 
     def _verify_monotonic_timestamps(self, data, last_ts: int, name: str):
         if len(data) == 0:
@@ -418,16 +438,17 @@ class Worker:
         # if there are multiple rows, check that all timestamps are increasing
         if len(data) > 1 and np.min(np.diff(data['timestamp'])) <= 0:
             min_idx = np.argmin(np.diff(data['timestamp']))
-            log.warning("Non-monotonic timestamp in [%s], restarting module" % self.name)
-            self.log("Non-monotonic timestamp in stream [%s] (%d<=%d)" %
-                     (name, data['timestamp'][min_idx + 1], data['timestamp'][min_idx]))
-            log.warning("Non-monotonic timestamp in [%s], restarting module" % self.name)
+            msg = ("Non-monotonic timestamp in new data to stream [%s] (%d<=%d)" %
+                   (name, data['timestamp'][min_idx + 1], data['timestamp'][min_idx]))
+            log.warning(msg)
+            self.log(msg)
             return False
         # check to make sure the first timestamp is larger than the previous block
         if last_ts is not None:
             if last_ts >= data['timestamp'][0]:
-                log.warning("Non-monotonic timestamp in [%s], restarting module" % self.name)
-                self.log("Non-monotonic timestamp in stream [%s] (%d<=%d)" %
-                         (name, data['timestamp'][0], last_ts))
+                msg = ("Non-monotonic timestamp between writes to stream [%s] (%d<=%d)" %
+                       (name, data['timestamp'][0], last_ts))
+                log.warning(msg)
+                self.log(msg)
                 return False
         return True
